searchData={"items":[{"type":"module","title":"ExCart","doc":"Documentation for `ExCart`.","ref":"ExCart.html"},{"type":"function","title":"ExCart.hello/0","doc":"Hello world.","ref":"ExCart.html#hello/0"},{"type":"function","title":"Examples - ExCart.hello/0","doc":"iex> ExCart.hello()\n    :world","ref":"ExCart.html#hello/0-examples"},{"type":"module","title":"ExCart.Adjustment","doc":"Definition of the structure of an adjustment.","ref":"ExCart.Adjustment.html"},{"type":"function","title":"ExCart.Adjustment.new/5","doc":"Creates a structure based on:\n\n  `id`  Id of the adjustment\n\n  `name`  Name of the adjustment\n\n  `description` Description of the adjustment\n\n  `type` Type of the adjustment\n\n  `function` Anonymous function to be used by `ExCart`","ref":"ExCart.Adjustment.html#new/5"},{"type":"module","title":"ExCart.Cart","doc":"Module to handle `ExCart` structures.","ref":"ExCart.Cart.html"},{"type":"function","title":"ExCart.Cart.add_adjustment/2","doc":"Add adjustment to the adjustment list.","ref":"ExCart.Cart.html#add_adjustment/2"},{"type":"function","title":"Examples - ExCart.Cart.add_adjustment/2","doc":"iex> ex_cart = ExCart.Cart.new\n      iex> adj = ExCart.Adjustment.new(\"shipping\",\"Shipping\",\n      ...> fn(x) ->\n      ...> sb = ExCart.Cart.subtotal(x)\n      ...>  case sb do\n      ...>    sb when sb > 25 -> 0\n      ...>    _-> 10\n      ...>   end\n      iex> end)\n      iex> ex_cart = ExCart.Cart.add_adjustment(ex_cart,adj)\n      iex> length ex_cart.adjustments\n      1","ref":"ExCart.Cart.html#add_adjustment/2-examples"},{"type":"function","title":"ExCart.Cart.add_item/2","doc":"Add a new item into the %ExCart.Cart{} structure, if the item already exists on the\n  structure, this function will update the quantity.","ref":"ExCart.Cart.html#add_item/2"},{"type":"function","title":"Examples - ExCart.Cart.add_item/2","doc":"iex> ex_cart = ExCart.Cart.new\n      iex> ex_cart = ExCart.Cart.add_item(ex_cart,%ExCart.Item{ sku: \"SU04\", qty: 1, price: 3 })\n      iex> ex_cart = ExCart.Cart.add_item(ex_cart,%ExCart.Item{ sku: \"SU04\", qty: 1, price: 3 })\n      %ExCart.Cart{adjustments: [],items: [%ExCart.Item{attr: %{}, price: 3, qty: 2, sku: \"SU04\"}]}\n      iex> ExCart.Cart.subtotal(ex_cart)\n      6","ref":"ExCart.Cart.html#add_item/2-examples"},{"type":"function","title":"ExCart.Cart.clear/1","doc":"Clear the Cart.","ref":"ExCart.Cart.html#clear/1"},{"type":"function","title":"ExCart.Cart.clear_adjustments/1","doc":"Clear adjustments from the Cart.","ref":"ExCart.Cart.html#clear_adjustments/1"},{"type":"function","title":"ExCart.Cart.clear_items/1","doc":"Clear items from the Cart.","ref":"ExCart.Cart.html#clear_items/1"},{"type":"function","title":"ExCart.Cart.get_adjustment/2","doc":"Get the Adjustment.","ref":"ExCart.Cart.html#get_adjustment/2"},{"type":"function","title":"ExCart.Cart.get_adjustment_result/2","doc":"Get the Adjustment Result.","ref":"ExCart.Cart.html#get_adjustment_result/2"},{"type":"function","title":"ExCart.Cart.new/0","doc":"Creates an empty %ExCart.Cart{} structure, this structure has by default\n  and empty list of items and and empty list of adjustments","ref":"ExCart.Cart.html#new/0"},{"type":"function","title":"Examples - ExCart.Cart.new/0","doc":"iex> ExCart.Cart.new\n      %ExCart.Cart{adjustments: [], items: []}","ref":"ExCart.Cart.html#new/0-examples"},{"type":"function","title":"ExCart.Cart.remove_adjustment/2","doc":"Remove adjustment from adjustment list.","ref":"ExCart.Cart.html#remove_adjustment/2"},{"type":"function","title":"Examples - ExCart.Cart.remove_adjustment/2","doc":"iex> ex_cart = ExCart.Cart.new\n  iex> adj = ExCart.Adjustment.new(\"shipping\",\"Shipping\",\n  ...> fn(x) ->\n  ...> sb = ExCart.Cart.subtotal(x)\n  ...>  case sb do\n  ...>    sb when sb > 25 -> 0\n  ...>    _-> 10\n  ...>   end\n  iex> end)\n  iex> ex_cart = ExCart.Cart.add_adjustment(ex_cart, adj)\n  iex> length ex_cart.adjustments\n  1\n  iex> ex_cart = ExCart.Cart.remove_adjustment(ex_cart, \"shipping\")\n  iex> length ex_cart.adjustments\n  0","ref":"ExCart.Cart.html#remove_adjustment/2-examples"},{"type":"function","title":"ExCart.Cart.subtotal/1","doc":"Calculate the sum of the result of multiply the price of each item and its quantity","ref":"ExCart.Cart.html#subtotal/1"},{"type":"function","title":"Examples - ExCart.Cart.subtotal/1","doc":"iex> ex_cart = ExCart.Cart.new\n      iex> ex_cart = ExCart.Cart.add_item(ex_cart,%ExCart.Item{ sku: \"SU04\", qty: 10, price: 2 })\n      iex> ExCart.Cart.subtotal(ex_cart)\n      20","ref":"ExCart.Cart.html#subtotal/1-examples"},{"type":"function","title":"ExCart.Cart.total/1","doc":"Calculates the total of the cart that include: subtotal + adjustments","ref":"ExCart.Cart.html#total/1"},{"type":"function","title":"Examples - ExCart.Cart.total/1","doc":"iex> ex_cart = ExCart.Cart.new\n    iex> ex_cart = ExCart.Cart.add_item(ex_cart,%ExCart.Item{ sku: \"SU04\", qty: 5, price: 3 })\n    iex> adj = ExCart.Adjustment.new(\"shipping\",\"Shipping\",\n    ...> fn(x) ->\n    ...> sb = ExCart.Cart.subtotal(x)\n    ...>case sb do\n    ...>  sb when sb > 25 -> 0\n    ...>  _-> 10\n    ...>end\n    ...>end)\n    iex> ex_cart = ExCart.Cart.add_adjustment(ex_cart, adj)\n    iex> ExCart.Cart.total(ex_cart)\n    25","ref":"ExCart.Cart.html#total/1-examples"},{"type":"module","title":"ExCart.Cart.Supervisor","doc":"","ref":"ExCart.Cart.Supervisor.html"},{"type":"function","title":"ExCart.Cart.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExCart.Cart.Supervisor.html#child_spec/1"},{"type":"function","title":"ExCart.Cart.Supervisor.init/1","doc":"","ref":"ExCart.Cart.Supervisor.html#init/1"},{"type":"function","title":"ExCart.Cart.Supervisor.remove_cart/1","doc":"","ref":"ExCart.Cart.Supervisor.html#remove_cart/1"},{"type":"function","title":"ExCart.Cart.Supervisor.start_cart/0","doc":"","ref":"ExCart.Cart.Supervisor.html#start_cart/0"},{"type":"function","title":"ExCart.Cart.Supervisor.start_link/1","doc":"","ref":"ExCart.Cart.Supervisor.html#start_link/1"},{"type":"module","title":"ExCart.Item","doc":"Definition of the structure of an Item used by ExCart","ref":"ExCart.Item.html"},{"type":"function","title":"ExCart.Item.new/4","doc":"Creates a structure based on: \n\n  `sku` SKU of the item\n\n  `price` Float that represents the price of the item\n\n  `qty` Number that represents the quantity of the item\n\n  `attr` Additional attributes that needs to be attached to the item, like description, name, etc.","ref":"ExCart.Item.html#new/4"},{"type":"module","title":"ExCart.Macros","doc":"","ref":"ExCart.Macros.html"},{"type":"module","title":"ExCart.Macros.Adjustment","doc":"","ref":"ExCart.Macros.Adjustment.html"},{"type":"module","title":"ExCart.Macros.Cart","doc":"","ref":"ExCart.Macros.Cart.html"},{"type":"module","title":"ExCart.Macros.Item","doc":"","ref":"ExCart.Macros.Item.html"},{"type":"module","title":"ExCart.Macros.Server","doc":"","ref":"ExCart.Macros.Server.html"},{"type":"module","title":"ExCart.Server","doc":"","ref":"ExCart.Server.html"},{"type":"function","title":"ExCart.Server.add_adjustment/2","doc":"","ref":"ExCart.Server.html#add_adjustment/2"},{"type":"function","title":"ExCart.Server.add_item/2","doc":"","ref":"ExCart.Server.html#add_item/2"},{"type":"function","title":"ExCart.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExCart.Server.html#child_spec/1"},{"type":"function","title":"ExCart.Server.clear/1","doc":"","ref":"ExCart.Server.html#clear/1"},{"type":"function","title":"ExCart.Server.clear_adjustments/1","doc":"","ref":"ExCart.Server.html#clear_adjustments/1"},{"type":"function","title":"ExCart.Server.clear_items/1","doc":"","ref":"ExCart.Server.html#clear_items/1"},{"type":"function","title":"ExCart.Server.init/1","doc":"","ref":"ExCart.Server.html#init/1"},{"type":"function","title":"ExCart.Server.remove_adjustment/2","doc":"","ref":"ExCart.Server.html#remove_adjustment/2"},{"type":"function","title":"ExCart.Server.start_link/0","doc":"","ref":"ExCart.Server.html#start_link/0"},{"type":"function","title":"ExCart.Server.state/1","doc":"","ref":"ExCart.Server.html#state/1"},{"type":"function","title":"ExCart.Server.subtotal/1","doc":"","ref":"ExCart.Server.html#subtotal/1"},{"type":"function","title":"ExCart.Server.total/1","doc":"","ref":"ExCart.Server.html#total/1"},{"type":"extras","title":"ExCart","doc":"# ExCart\nE-commerce cart for elixir\n\n[![Coverage Status](https://coveralls.io/repos/github/data-twister/ex_cart/badge.svg?branch=main)](https://coveralls.io/github/data-twister/ex_cart?branch=main)\n![CircleCI](https://img.shields.io/circleci/build/github/data-twister/ex_cart)\n[![Version](https://img.shields.io/hexpm/v/ex_cart.svg?style=flat-square)](https://hex.pm/packages/ex_cart)\n![GitHub](https://img.shields.io/github/license/data-twister/ex_cart)\n![GitHub last commit (branch)](https://img.shields.io/github/last-commit/data-twister/ex_cart/main)","ref":"readme.html"},{"type":"extras","title":"Installation - ExCart","doc":"- clone the repo\n    - cd ex_cart\n    - mix deps.get","ref":"readme.html#installation"},{"type":"extras","title":"Run on iex - ExCart","doc":"iex -S mix","ref":"readme.html#run-on-iex"},{"type":"extras","title":"Use to store values - ExCart","doc":"ex_cart = ExCart.Cart.new\n    ex_cart = ExCart.Cart.add_item(ex_cart, %ExCart.Item{ec_sku: \"SU04\", ec_qty: 10, ec_price: 3})\n    adj = ExCart.Adjustment.new(\"shipping\",\"Shipping\",\n      fn(x) ->\n      sb = ExCart.Cart.subtotal(x)\n        case sb do\n          sb when sb > 25 -> 0\n          _-> 10\n        end\n    end)\n    ex_cart = ExCart.Cart.add_adjustment(ex_cart,adj)\n    ExCart.Cart.total(ex_cart)","ref":"readme.html#use-to-store-values"},{"type":"extras","title":"Use as server (manage multiple cart processes and their states). - ExCart","doc":"{:ok, pid1} = ExCart.Server.start_link\n    ExCart.Server.add_item(pid1, %ExCart.Item{ec_sku: \"SU01\", ec_qty: 10, ec_price: 3})\n    {:ok, pid2} = ExCart.Server.start_link\n    ExCart.Server.add_item(pid2, %ExCart.Item{ec_sku: \"SU02\", ec_qty: 5, ec_price: 3})\n    adj = ExCart.Adjustment.new(\"shipping\",\"Shipping\",\n        fn(x) ->\n            sb = ExCart.Cart.subtotal(x)\n                case sb do\n                    sb when sb > 25 -> 0\n                    _-> 10\n                end\n        end)\n    ExCart.Server.add_adjustment(pid1,adj)\n    ExCart.Server.add_adjustment(pid2,adj)\n    ExCart.Server.total(pid1)\n    ExCart.Server.total(pid2)","ref":"readme.html#use-as-server-manage-multiple-cart-processes-and-their-states"},{"type":"extras","title":"How to use the registry to manage multiple ExCartServers - ExCart","doc":"{:ok, session } = ExCart.Session.start_link\n    cart_one = ExCart.Session.server_process(\"cart one\")\n    ExCart.Server.add_item(cart_one, %ExCart.Item{ec_sku: \"SU01\", ec_price: 10})\n    ExCart.Server.add_item(cart_one, %ExCart.Item{ec_sku: \"SU02\", ec_price: 15})\n    ExCart.Server.subtotal(cart_one)\n\n    cart_two = ExCart.Session.server_process(\"cart two\")\n    ExCart.Server.add_item(cart_two, %ExCart.Item{ec_sku: \"SU01\", ec_price: 2})\n    ExCart.Server.add_item(cart_two, %ExCart.Item{ec_sku: \"SU03\", ec_price: 1})\n    ExCart.Server.subtotal(cart_two)","ref":"readme.html#how-to-use-the-registry-to-manage-multiple-excartservers"},{"type":"extras","title":"How to use the Dynamic Supervised ExCartServers - ExCart","doc":"{:ok, pid } = ExCart.Cart.Supervisor.start_cart()\n    ExCart.Server.state(pid)","ref":"readme.html#how-to-use-the-dynamic-supervised-excartservers"},{"type":"extras","title":"How to use the supervisor as starting point. - ExCart","doc":"ExCart.Supervisor.start_link\n    cart_one = ExCart.Session.server_process(\"cart one\")\n    ExCart.Server.add_item(cart_one, %ExCart.Item{ec_sku: \"SU01\", ec_price: 10})\n    ExCart.Server.add_item(cart_one, %ExCart.Item{ec_sku: \"SU02\", ec_price: 15})\n    ExCart.Server.subtotal(cart_one)\n\n#","ref":"readme.html#how-to-use-the-supervisor-as-starting-point"},{"type":"extras","title":"To use with Phoenix: - ExCart","doc":"- Add as dependency \n  - To see how it works, start the application on iex\n  \n      $ iex -S mix phoenix.server\n      \n      #And then start the observer.\n      \n      iex(n)>:observer.start\n        \n      #And you will see the ex_cart application aside of your app.","ref":"readme.html#to-use-with-phoenix"},{"type":"extras","title":"Settings (config.exs) - ExCart","doc":"- config :ex_cart, max_items: 1000","ref":"readme.html#settings-config-exs"},{"type":"extras","title":"License - ExCart","doc":"Copyright 2022 Jason Clark\nCopyright 2018 Ruben Amortegui\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"}],"content_type":"text/markdown"}